django-project-portfolio |version|
==================================

django-project-portfolio is a `Django
<https://www.djangoproject.com/>`_ application for displaying
information about software projects you maintain.

:ref:`Models <models>` are included for storing information about
projects, versions of projects, the status of each release and
associated metadata including licensing and location of packages,
source code, documentation and continuous integration. :ref:`Built-in
views <views>` are provided for basic display of this information.


Documentation contents
----------------------

.. toctree::
   :maxdepth: 1

   install
   models
   views